==> estateplat-common-1.2.4-20201120.060252-533-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGyJzdBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttGyJzd;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttGyJzdBdc extends KttGyJzd {
    private String dfjblxdm;
    private String dfjblxmc;
    private String dfjzdlxdm;
    private String dfjzdlxmc;
    @XmlAttribute(
            name = "DFJBLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjblxdm() {
        return dfjblxdm;
    }

    public void setDfjblxdm(String dfjblxdm) {
        this.dfjblxdm = dfjblxdm;
    }
    @XmlAttribute(
            name = "DFJBLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjblxmc() {
        return dfjblxmc;
    }

    public void setDfjblxmc(String dfjblxmc) {
        this.dfjblxmc = dfjblxmc;
    }
    @XmlAttribute(
            name = "DFJZDLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzdlxdm() {
        return dfjzdlxdm;
    }

    public void setDfjzdlxdm(String dfjzdlxdm) {
        this.dfjzdlxdm = dfjzdlxdm;
    }
    @XmlAttribute(
            name = "DFJZDLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzdlxmc() {
        return dfjzdlxmc;
    }

    public void setDfjzdlxmc(String dfjzdlxmc) {
        this.dfjzdlxmc = dfjzdlxmc;
    }
}

==> estateplat-common-1.2.4-20231205.063949-1201-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGyJzdBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.newStandard.KttGyJzdNew;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
@Table(name = "KTT_GY_JZD")
public class KttGyJzdBdc extends KttGyJzdNew {
    private String dfjblxdm;
    private String dfjblxmc;
    private String dfjzdlxdm;
    private String dfjzdlxmc;
    @XmlAttribute(
            name = "DFJBLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjblxdm() {
        return dfjblxdm;
    }

    public void setDfjblxdm(String dfjblxdm) {
        this.dfjblxdm = dfjblxdm;
    }
    @XmlAttribute(
            name = "DFJBLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjblxmc() {
        return dfjblxmc;
    }

    public void setDfjblxmc(String dfjblxmc) {
        this.dfjblxmc = dfjblxmc;
    }
    @XmlAttribute(
            name = "DFJZDLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzdlxdm() {
        return dfjzdlxdm;
    }

    public void setDfjzdlxdm(String dfjzdlxdm) {
        this.dfjzdlxdm = dfjzdlxdm;
    }
    @XmlAttribute(
            name = "DFJZDLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzdlxmc() {
        return dfjzdlxmc;
    }

    public void setDfjzdlxmc(String dfjzdlxmc) {
        this.dfjzdlxmc = dfjzdlxmc;
    }
}
